@@ -7,36 +7,40 @@ import SciMLBase: OptimizationFunction
 import OptimizationBase.LinearAlgebra: I, dot
 import DifferentiationInterface
 import DifferentiationInterface: prepare_gradient, prepare_hessian, prepare_hvp,
-                                 prepare_pullback, prepare_pushforward, pullback!,
-                                 pushforward!,
-                                 pullback, pushforward,
-                                 prepare_jacobian, value_and_gradient!, value_and_gradient,
-                                 value_derivative_and_second_derivative!,
-                                 value_derivative_and_second_derivative,
-                                 gradient!, hessian!, hvp!, jacobian!, gradient, hessian,
-                                 hvp, jacobian, Constant
+    prepare_pullback, prepare_pushforward, pullback!,
+    pushforward!,
+    pullback, pushforward,
+    prepare_jacobian, value_and_gradient!, value_and_gradient,
+    value_derivative_and_second_derivative!,
+    value_derivative_and_second_derivative,
+    gradient!, hessian!, hvp!, jacobian!, gradient, hessian,
+    hvp, jacobian, Constant
 using ADTypes, SciMLBase
 import Zygote, Zygote.ForwardDiff
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, x,
-        adtype::Union{ADTypes.AutoZygote,
+        adtype::Union{
+            ADTypes.AutoZygote,
             DifferentiationInterface.SecondOrder{
-                <:ADTypes.AbstractADType, <:ADTypes.AutoZygote}},
+                <:ADTypes.AbstractADType, <:ADTypes.AutoZygote,
+            },
+        },
         p = SciMLBase.NullParameters(), num_cons = 0;
         g = false, h = false, hv = false, fg = false, fgh = false,
         cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-        lag_h = false)
+        lag_h = false
+    )
     adtype, soadtype = OptimizationBase.generate_adtype(adtype)
 
     if g == true && f.grad === nothing
         prep_grad = prepare_gradient(f.f, adtype, x, Constant(p), strict = Val(false))
         function grad(res, θ)
-            gradient!(f.f, res, prep_grad, adtype, θ, Constant(p))
+            return gradient!(f.f, res, prep_grad, adtype, θ, Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function grad(res, θ, p)
-                gradient!(f.f, res, prep_grad, adtype, θ, Constant(p))
+                return gradient!(f.f, res, prep_grad, adtype, θ, Constant(p))
             end
         end
     elseif g == true
@@ -70,11 +74,11 @@ function OptimizationBase.instantiate_function(
     if h == true && f.hess === nothing
         prep_hess = prepare_hessian(f.f, soadtype, x, Constant(p), strict = Val(false))
         function hess(res, θ)
-            hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+            return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hess(res, θ, p)
-                hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+                return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
             end
         end
     elseif h == true
@@ -85,18 +89,24 @@ function OptimizationBase.instantiate_function(
 
     if fgh == true && f.fgh === nothing
         function fgh!(G, H, θ)
-            (y,
+            (
+                y,
                 _,
-                _) = value_derivative_and_second_derivative!(
-                f.f, G, H, prep_hess, soadtype, θ, Constant(p))
+                _,
+            ) = value_derivative_and_second_derivative!(
+                f.f, G, H, prep_hess, soadtype, θ, Constant(p)
+            )
             return y
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function fgh!(G, H, θ, p)
-                (y,
+                (
+                    y,
                     _,
-                    _) = value_derivative_and_second_derivative!(
-                    f.f, G, H, prep_hess, soadtype, θ, Constant(p))
+                    _,
+                ) = value_derivative_and_second_derivative!(
+                    f.f, G, H, prep_hess, soadtype, θ, Constant(p)
+                )
                 return y
             end
         end
@@ -109,11 +119,11 @@ function OptimizationBase.instantiate_function(
     if hv == true && f.hv === nothing
         prep_hvp = prepare_hvp(f.f, soadtype, x, (zeros(eltype(x), size(x)),), Constant(p), strict = Val(false))
         function hv!(H, θ, v)
-            hvp!(f.f, (H,), prep_hvp, soadtype, θ, (v,), Constant(p))
+            return hvp!(f.f, (H,), prep_hvp, soadtype, θ, (v,), Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hv!(H, θ, v, p)
-                hvp!(f.f, (H,), prep_hvp, soadtype, θ, (v,), Constant(p))
+                return hvp!(f.f, (H,), prep_hvp, soadtype, θ, (v,), Constant(p))
             end
         end
     elseif hv == true
@@ -150,7 +160,7 @@ function OptimizationBase.instantiate_function(
         prep_jac = prepare_jacobian(cons_oop, adtype, x, strict = Val(false))
         function cons_j!(J, θ)
             jacobian!(cons_oop, J, prep_jac, adtype, θ)
-            if size(J, 1) == 1
+            return if size(J, 1) == 1
                 J = vec(J)
             end
         end
@@ -162,9 +172,10 @@ function OptimizationBase.instantiate_function(
 
     if f.cons_vjp === nothing && cons_vjp == true && cons !== nothing
         prep_pullback = prepare_pullback(
-            cons_oop, adtype, x, (ones(eltype(x), num_cons),), strict = Val(false))
+            cons_oop, adtype, x, (ones(eltype(x), num_cons),), strict = Val(false)
+        )
         function cons_vjp!(J, θ, v)
-            pullback!(cons_oop, (J,), prep_pullback, adtype, θ, (v,))
+            return pullback!(cons_oop, (J,), prep_pullback, adtype, θ, (v,))
         end
     elseif cons_vjp == true
         cons_vjp! = (J, θ, v) -> f.cons_vjp(J, θ, v, p)
@@ -174,9 +185,10 @@ function OptimizationBase.instantiate_function(
 
     if cons !== nothing && f.cons_jvp === nothing && cons_jvp == true
         prep_pushforward = prepare_pushforward(
-            cons_oop, adtype, x, (ones(eltype(x), length(x)),), strict = Val(false))
+            cons_oop, adtype, x, (ones(eltype(x), length(x)),), strict = Val(false)
+        )
         function cons_jvp!(J, θ, v)
-            pushforward!(cons_oop, (J,), prep_pushforward, adtype, θ, (v,))
+            return pushforward!(cons_oop, (J,), prep_pushforward, adtype, θ, (v,))
         end
     elseif cons_jvp == true
         cons_jvp! = (J, θ, v) -> f.cons_jvp(J, θ, v, p)
@@ -189,9 +201,12 @@ function OptimizationBase.instantiate_function(
 
     # Prepare constraint Hessian preparations if needed by lag_h or cons_h
     if cons !== nothing && f.cons_h === nothing && (cons_h == true || lag_h == true)
-        prep_cons_hess = [prepare_hessian(
-                              cons_oop, soadtype, x, Constant(i), strict = Val(false))
-                          for i in 1:num_cons]
+        prep_cons_hess = [
+            prepare_hessian(
+                    cons_oop, soadtype, x, Constant(i), strict = Val(false)
+                )
+                for i in 1:num_cons
+        ]
     else
         prep_cons_hess = nothing
     end
@@ -204,6 +219,7 @@ function OptimizationBase.instantiate_function(
                 for i in 1:num_cons
                     hessian!(cons_oop, H[i], prep_cons_hess[i], soadtype, θ, Constant(i))
                 end
+                return
             end
         else
             cons_h! = nothing
@@ -227,6 +243,7 @@ function OptimizationBase.instantiate_function(
                     @. H += λ[i] * Hi
                 end
             end
+            return
         end
     elseif cons !== nothing && cons_h == true
         cons_h! = (res, θ) -> f.cons_h(res, θ, p)
@@ -241,22 +258,26 @@ function OptimizationBase.instantiate_function(
     if f.lag_h === nothing && cons !== nothing && lag_h == true
         lag_extras = prepare_hessian(
             lagrangian, soadtype, x, Constant(one(eltype(x))),
-            Constant(ones(eltype(x), num_cons)), Constant(p), strict = Val(false))
+            Constant(ones(eltype(x), num_cons)), Constant(p), strict = Val(false)
+        )
         lag_hess_prototype = zeros(Bool, length(x), length(x))
 
         function lag_h!(H::AbstractMatrix, θ, σ, λ)
-            if σ == zero(eltype(θ))
+            return if σ == zero(eltype(θ))
                 # When σ=0, use the weighted sum function
                 cons_h_weighted!(H, θ, λ)
             else
-                hessian!(lagrangian, H, lag_extras, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                hessian!(
+                    lagrangian, H, lag_extras, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
             end
         end
 
         function lag_h!(h::AbstractVector, θ, σ, λ)
             H = hessian(
-                lagrangian, lag_extras, soadtype, θ, Constant(σ), Constant(λ), Constant(p))
+                lagrangian, lag_extras, soadtype, θ, Constant(σ), Constant(λ), Constant(p)
+            )
             k = 0
             for i in 1:length(θ)
                 for j in 1:i
@@ -264,22 +285,27 @@ function OptimizationBase.instantiate_function(
                     h[k] = H[i, j]
                 end
             end
+            return
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function lag_h!(H::AbstractMatrix, θ, σ, λ, p)
-                if σ == zero(eltype(θ))
+                return if σ == zero(eltype(θ))
                     cons_h(H, θ)
                     H *= λ
                 else
-                    hessian!(lagrangian, H, lag_extras, soadtype, θ,
-                        Constant(σ), Constant(λ), Constant(p))
+                    hessian!(
+                        lagrangian, H, lag_extras, soadtype, θ,
+                        Constant(σ), Constant(λ), Constant(p)
+                    )
                 end
             end
 
             function lag_h!(h::AbstractVector, θ, σ, λ, p)
-                H = hessian(lagrangian, lag_extras, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                H = hessian(
+                    lagrangian, lag_extras, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
                 k = 0
                 for i in 1:length(θ)
                     for j in 1:i
@@ -287,6 +313,7 @@ function OptimizationBase.instantiate_function(
                         h[k] = H[i, j]
                     end
                 end
+                return
             end
         end
     elseif cons !== nothing && lag_h == true
@@ -295,7 +322,8 @@ function OptimizationBase.instantiate_function(
         lag_h! = nothing
     end
 
-    return OptimizationFunction{true}(f.f, adtype;
+    return OptimizationFunction{true}(
+        f.f, adtype;
         grad = grad, fg = fg!, hess = hess, hv = hv!, fgh = fgh!,
         cons = cons, cons_j = cons_j!, cons_h = cons_h!,
         cons_vjp = cons_vjp!, cons_jvp = cons_jvp!,
@@ -309,51 +337,64 @@ function OptimizationBase.instantiate_function(
         lag_hess_prototype = lag_hess_prototype,
         sys = f.sys,
         expr = f.expr,
-        cons_expr = f.cons_expr)
+        cons_expr = f.cons_expr
+    )
 end
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, cache::OptimizationBase.ReInitCache,
-        adtype::ADTypes.AutoZygote, num_cons = 0; kwargs...)
+        adtype::ADTypes.AutoZygote, num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
     return OptimizationBase.instantiate_function(
-        f, x, adtype, p, num_cons; kwargs...)
+        f, x, adtype, p, num_cons; kwargs...
+    )
 end
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, cache::OptimizationBase.ReInitCache,
         adtype::DifferentiationInterface.SecondOrder{
-            <:ADTypes.AbstractADType, <:ADTypes.AutoZygote},
-        num_cons = 0; kwargs...)
+            <:ADTypes.AbstractADType, <:ADTypes.AutoZygote,
+        },
+        num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
     return OptimizationBase.instantiate_function(
-        f, x, adtype, p, num_cons; kwargs...)
+        f, x, adtype, p, num_cons; kwargs...
+    )
 end
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, x,
-        adtype::ADTypes.AutoSparse{<:Union{ADTypes.AutoZygote,
-            DifferentiationInterface.SecondOrder{
-                <:ADTypes.AbstractADType, <:ADTypes.AutoZygote}}},
+        adtype::ADTypes.AutoSparse{
+            <:Union{
+                ADTypes.AutoZygote,
+                DifferentiationInterface.SecondOrder{
+                    <:ADTypes.AbstractADType, <:ADTypes.AutoZygote,
+                },
+            },
+        },
         p = SciMLBase.NullParameters(), num_cons = 0;
         g = false, h = false, hv = false, fg = false, fgh = false,
         cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-        lag_h = false)
+        lag_h = false
+    )
     adtype, soadtype = OptimizationBase.generate_sparse_adtype(adtype)
 
     if g == true && f.grad === nothing
         extras_grad = prepare_gradient(
-            f.f, adtype.dense_ad, x, Constant(p), strict = Val(false))
+            f.f, adtype.dense_ad, x, Constant(p), strict = Val(false)
+        )
         function grad(res, θ)
-            gradient!(f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
+            return gradient!(f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function grad(res, θ, p)
-                gradient!(f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
+                return gradient!(f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
             end
         end
     elseif g == true
@@ -365,19 +406,26 @@ function OptimizationBase.instantiate_function(
     if fg == true && f.fg === nothing
         if g == false
             extras_grad = prepare_gradient(
-                f.f, adtype.dense_ad, x, Constant(p), strict = Val(false))
+                f.f, adtype.dense_ad, x, Constant(p), strict = Val(false)
+            )
         end
         function fg!(res, θ)
-            (y,
-                _) = value_and_gradient!(
-                f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
+            (
+                y,
+                _,
+            ) = value_and_gradient!(
+                f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p)
+            )
             return y
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function fg!(res, θ, p)
-                (y,
-                    _) = value_and_gradient!(
-                    f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p))
+                (
+                    y,
+                    _,
+                ) = value_and_gradient!(
+                    f.f, res, extras_grad, adtype.dense_ad, θ, Constant(p)
+                )
                 return y
             end
         end
@@ -392,14 +440,14 @@ function OptimizationBase.instantiate_function(
     if h == true && f.hess === nothing
         prep_hess = prepare_hessian(f.f, soadtype, x, Constant(p), strict = Val(false))
         function hess(res, θ)
-            hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+            return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
         end
         hess_sparsity = prep_hess.coloring_result.A
         hess_colors = prep_hess.coloring_result.color
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hess(res, θ, p)
-                hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+                return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
             end
         end
     elseif h == true
@@ -410,19 +458,25 @@ function OptimizationBase.instantiate_function(
 
     if fgh == true && f.fgh === nothing
         function fgh!(G, H, θ)
-            (y,
+            (
+                y,
                 _,
-                _) = value_derivative_and_second_derivative!(
-                f.f, G, H, θ, prep_hess, soadtype, Constant(p))
+                _,
+            ) = value_derivative_and_second_derivative!(
+                f.f, G, H, θ, prep_hess, soadtype, Constant(p)
+            )
             return y
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function fgh!(G, H, θ, p)
-                (y,
+                (
+                    y,
                     _,
-                    _) = value_derivative_and_second_derivative!(
-                    f.f, G, H, θ, prep_hess, soadtype, Constant(p))
+                    _,
+                ) = value_derivative_and_second_derivative!(
+                    f.f, G, H, θ, prep_hess, soadtype, Constant(p)
+                )
                 return y
             end
         end
@@ -434,13 +488,14 @@ function OptimizationBase.instantiate_function(
 
     if hv == true && f.hv === nothing
         prep_hvp = prepare_hvp(
-            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p))
+            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p)
+        )
         function hv!(H, θ, v)
-            hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p))
+            return hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hv!(H, θ, v, p)
-                hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p))
+                return hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p))
             end
         end
     elseif hv == true
@@ -477,7 +532,7 @@ function OptimizationBase.instantiate_function(
         prep_jac = prepare_jacobian(cons_oop, adtype, x)
         function cons_j!(J, θ)
             jacobian!(cons_oop, J, prep_jac, adtype, θ)
-            if size(J, 1) == 1
+            return if size(J, 1) == 1
                 J = vec(J)
             end
         end
@@ -491,10 +546,12 @@ function OptimizationBase.instantiate_function(
 
     if f.cons_vjp === nothing && cons_vjp == true && cons !== nothing
         extras_pullback = prepare_pullback(
-            cons_oop, adtype.dense_ad, x, (ones(eltype(x), num_cons),))
+            cons_oop, adtype.dense_ad, x, (ones(eltype(x), num_cons),)
+        )
         function cons_vjp!(J, θ, v)
-            pullback!(
-                cons_oop, (J,), extras_pullback, adtype.dense_ad, θ, (v,))
+            return pullback!(
+                cons_oop, (J,), extras_pullback, adtype.dense_ad, θ, (v,)
+            )
         end
     elseif cons_vjp == true
         cons_vjp! = (J, θ, v) -> f.cons_vjp(J, θ, v, p)
@@ -504,10 +561,12 @@ function OptimizationBase.instantiate_function(
 
     if f.cons_jvp === nothing && cons_jvp == true && cons !== nothing
         extras_pushforward = prepare_pushforward(
-            cons_oop, adtype.dense_ad, x, (ones(eltype(x), length(x)),))
+            cons_oop, adtype.dense_ad, x, (ones(eltype(x), length(x)),)
+        )
         function cons_jvp!(J, θ, v)
-            pushforward!(
-                cons_oop, (J,), extras_pushforward, adtype.dense_ad, θ, (v,))
+            return pushforward!(
+                cons_oop, (J,), extras_pushforward, adtype.dense_ad, θ, (v,)
+            )
         end
     elseif cons_jvp == true
         cons_jvp! = (J, θ, v) -> f.cons_jvp(J, θ, v, p)
@@ -518,9 +577,12 @@ function OptimizationBase.instantiate_function(
     conshess_sparsity = f.cons_hess_prototype
     conshess_colors = f.cons_hess_colorvec
     if cons !== nothing && f.cons_h === nothing && cons_h == true
-        prep_cons_hess = [prepare_hessian(
-                              cons_oop, soadtype, x, Constant(i), strict = Val(false))
-                          for i in 1:num_cons]
+        prep_cons_hess = [
+            prepare_hessian(
+                    cons_oop, soadtype, x, Constant(i), strict = Val(false)
+                )
+                for i in 1:num_cons
+        ]
         colores = getfield.(prep_cons_hess, :coloring_result)
         conshess_sparsity = getfield.(colores, :A)
         conshess_colors = getfield.(colores, :color)
@@ -528,6 +590,7 @@ function OptimizationBase.instantiate_function(
             for i in 1:num_cons
                 hessian!(cons_oop, H[i], prep_cons_hess[i], soadtype, θ, Constant(i))
             end
+            return
         end
     elseif cons_h == true
         cons_h! = (res, θ) -> f.cons_h(res, θ, p)
@@ -540,23 +603,27 @@ function OptimizationBase.instantiate_function(
     if cons !== nothing && f.lag_h === nothing && lag_h == true
         lag_extras = prepare_hessian(
             lagrangian, soadtype, x, Constant(one(eltype(x))),
-            Constant(ones(eltype(x), num_cons)), Constant(p), strict = Val(false))
+            Constant(ones(eltype(x), num_cons)), Constant(p), strict = Val(false)
+        )
         lag_hess_prototype = lag_extras.coloring_result.A
         lag_hess_colors = lag_extras.coloring_result.color
 
         function lag_h!(H::AbstractMatrix, θ, σ, λ)
-            if σ == zero(eltype(θ))
+            return if σ == zero(eltype(θ))
                 # When σ=0, use the weighted sum function
                 cons_h_weighted!(H, θ, λ)
             else
-                hessian!(lagrangian, H, lag_extras, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                hessian!(
+                    lagrangian, H, lag_extras, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
             end
         end
 
         function lag_h!(h, θ, σ, λ)
             H = hessian(
-                lagrangian, lag_extras, soadtype, θ, Constant(σ), Constant(λ), Constant(p))
+                lagrangian, lag_extras, soadtype, θ, Constant(σ), Constant(λ), Constant(p)
+            )
             k = 0
             rows, cols, _ = findnz(H)
             for (i, j) in zip(rows, cols)
@@ -565,22 +632,27 @@ function OptimizationBase.instantiate_function(
                     h[k] = H[i, j]
                 end
             end
+            return
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function lag_h!(H::AbstractMatrix, θ, σ, λ, p)
-                if σ == zero(eltype(θ))
+                return if σ == zero(eltype(θ))
                     cons_h!(H, θ)
                     H *= λ
                 else
-                    hessian!(lagrangian, H, lag_extras, soadtype, θ,
-                        Constant(σ), Constant(λ), Constant(p))
+                    hessian!(
+                        lagrangian, H, lag_extras, soadtype, θ,
+                        Constant(σ), Constant(λ), Constant(p)
+                    )
                 end
             end
 
             function lag_h!(h::AbstractVector, θ, σ, λ, p)
-                H = hessian(lagrangian, lag_extras, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                H = hessian(
+                    lagrangian, lag_extras, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
                 k = 0
                 for i in 1:length(θ)
                     for j in 1:i
@@ -588,6 +660,7 @@ function OptimizationBase.instantiate_function(
                         h[k] = H[i, j]
                     end
                 end
+                return
             end
         end
     elseif cons !== nothing && cons_h == true
@@ -595,7 +668,8 @@ function OptimizationBase.instantiate_function(
     else
         lag_h! = nothing
     end
-    return OptimizationFunction{true}(f.f, adtype;
+    return OptimizationFunction{true}(
+        f.f, adtype;
         grad = grad, fg = fg!, hess = hess, hv = hv!, fgh = fgh!,
         cons = cons, cons_j = cons_j!, cons_h = cons_h!,
         hess_prototype = hess_sparsity,
@@ -609,12 +683,14 @@ function OptimizationBase.instantiate_function(
         lag_hess_colorvec = lag_hess_colors,
         sys = f.sys,
         expr = f.expr,
-        cons_expr = f.cons_expr)
+        cons_expr = f.cons_expr
+    )
 end
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, cache::OptimizationBase.ReInitCache,
-        adtype::ADTypes.AutoSparse{<:AutoZygote}, num_cons = 0; kwargs...)
+        adtype::ADTypes.AutoSparse{<:AutoZygote}, num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
@@ -623,9 +699,13 @@ end
 
 function OptimizationBase.instantiate_function(
         f::OptimizationFunction{true}, cache::OptimizationBase.ReInitCache,
-        adtype::ADTypes.AutoSparse{<:DifferentiationInterface.SecondOrder{
-            <:ADTypes.AbstractADType, <:ADTypes.AutoZygote}},
-        num_cons = 0; kwargs...)
+        adtype::ADTypes.AutoSparse{
+            <:DifferentiationInterface.SecondOrder{
+                <:ADTypes.AbstractADType, <:ADTypes.AutoZygote,
+            },
+        },
+        num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
