@@ -12,22 +12,20 @@ prob = OptimizationProblem(optf, [0.4], structural_analysis = true)
 @test sol.cache.analysis_results.objective.curvature == SymbolicAnalysis.Convex
 @test sol.cache.analysis_results.constraints === nothing
 
-x0 = zeros(2)
-rosenbrock(x, p = nothing) = (1 - x[1])^2 + 100 * (x[2] - x[1]^2)^2
-l1 = rosenbrock(x0)
+cvx_x0 = zeros(2)
 
 optf = OptimizationFunction(rosenbrock, AutoEnzyme())
-prob = OptimizationProblem(optf, x0, structural_analysis = true)
+prob = OptimizationProblem(optf, cvx_x0, structural_analysis = true)
 @time res = solve(prob, OptimizationLBFGSB.LBFGSB(), maxiters = 100)
 @test res.cache.analysis_results.objective.curvature == SymbolicAnalysis.UnknownCurvature
 
-function con2_c(res, x, p)
+function cvx_con2_c(res, x, p)
     return res .= [x[1]^2 + x[2]^2, (x[2] * sin(x[1]) + x[1]) - 5]
 end
 
-optf = OptimizationFunction(rosenbrock, AutoZygote(), cons = con2_c)
+optf = OptimizationFunction(rosenbrock, AutoZygote(), cons = cvx_con2_c)
 prob = OptimizationProblem(
-    optf, x0, lcons = [1.0, -Inf], ucons = [1.0, 0.0],
+    optf, cvx_x0, lcons = [1.0, -Inf], ucons = [1.0, 0.0],
     lb = [-1.0, -1.0], ub = [1.0, 1.0], structural_analysis = true
 )
 @time res = solve(prob, OptimizationLBFGSB.LBFGSB(), maxiters = 100)
